#====================================================================
# Poisson-Prozess
#====================================================================
source("poissonprozess.r")

set.seed(453434)
par(mfrow=c(2,2))

poissonProzess(lambda=1, tmax=10)
poissonProzess(lambda=2, tmax=10)
poissonProzess(lambda=3, tmax=10)
poissonProzess(lambda=4, tmax=10)


#====================================================================
# Coal-Mining-Daten
#====================================================================
# Daten einlesen
coaldata <- scan("coal.dat")

# Parameter fuer Anzahl der Ereignisse bestimmen
n <- length(coaldata)

# Plot zur Deskription der Daten wie in der Angabe
par(mfrow = c(1, 1), mar = c(4.5, 4.5, 1, 1))
plot(coaldata, 1:n, type= "s", xlab = "Zeit [Tage]", lwd = 1.5,
     ylab = "Kumulierte Anzahl an Explosionen", ylim = c(0, 200))
rug(coaldata)

#------------------------------------------
# (a) Maximum-Likelihood-Schätzer bestimmen
(lambdaML <- n / max(coaldata))

#------------------------------------------
# (b) Histogramm der Zwischenzeiten zeichnen
zwZeiten <- diff(c(0, coaldata))

#par(mfrow=c(1,2))
hist(zwZeiten, prob = TRUE, nclass = 50, col = "grey70",
     xlab = expression(T[i]), main = "")

# Dichte der Exponentialverteilung mit Rate lambdaML einzeichnen
lines(0:2500, dexp(0:2500, rate = lambdaML), col = 2, lwd = 2)

# Zusatz:
# Quantil-Quantil-Plot mit Exponentialverteilung zeichnen
x <- rexp(10000, rate = lambdaML)
qqplot(x, zwZeiten, pch = ".", cex = 5, xlim = c(0, 2500), ylim = c(0, 2500),
       ylab = expression("Sample Quantiles of   "*T[i]), 
       xlab = expression("Theoretical Quantiles of  Exp ( "*hat(lambda)[ML]*" )"))
lines(c(0, 2500), c(0, 2500))

#------------------------------------------
# (c) Kolmogorov-Smirnov-Test

# Test der Nullhypothese, dass die Zwischenzeiten exponentialverteilt sind
(ks <- ks.test(zwZeiten, pexp, lambdaML))

# Ergebnis: p = 0.02672
# -> Die Nullhypothese wird auf dem 5%-Signifikanzniveau abgelehnt.