#====================================================================
# Simulation des Poisson-Prozesses
#====================================================================

#-----------------
# Input-Parameter:
#
# lambda:     Rate des Poisson-Prozesses
# tmax:       Zeitpunkt, bis zu dem der Poisson-Prozess simuliert werden soll
# plot:       Plot-Parameter fuer Visualisierung des Pfades in
#             einer Treppenfunktion
# ...         Weitere Argumente fuer die plot Funktion

#-----------------
# Output:
# data.frame mit zwei Spalten fuer Zeitpunkte und Pfad

poissonProzess <- function(lambda = 1, tmax = 5, plot = TRUE, ...)	{
  
  # Vektor mit Ereigniszeitpunkten initialisieren
  zeit <- 0
  
  # Laufindex definieren in Vorbereitung auf die while-Schleife
  i <- 1
  
  # Solange neue Ereigniszeitpunkte simulieren, 
  # bis die Zeit t ueberschritten wird
  while(zeit[i] < tmax) {
    zeit <- c(zeit,zeit[i] + rexp(1, rate = lambda))
    i <- i+1
  }
  
  # Anzahl der simulierten Zeiten bestimmen (inklusive der 0-Zeit!)
  n <- length(zeit)
  
  # Den letzten Zeitpunkt umdefinieren und die zugehoerigen 
  # Zustaende des Poisson-Prozesses definieren
  # Den letzten Zeitpunkt der schon ueber tmax liegt auf tmax setzen
  zeit[n] <- tmax
  
  # In dem Zeit Vektor stehen nun 'n-2' Spruenge, 
  # da der erste Sprung am Index 2 passiert und der letzte am Index n-1
  
  # Den Pfad Vektor aufbauen als n-2 Spruenge, beginnend bei 0 und 
  # hinten dran nochmals den letzten Zustand
  pfad <- c(0:(n-2),n-2)
  
  # Alles in ein data.frame packen
  pp <- data.frame(zeit = zeit,pfad = pfad)
  
  if(plot) {
    # Damit es etwas schoener aussieht, erst das Drumherum gezeichnet
    plot(pp$zeit, pp$pfad, xlab = "t", ylab = "N(t)",
         type = 'n', cex.lab = 1.2,
         main = bquote(lambda == .(lambda)), ...)
    # Nun werden die Linien eingefuegt
    segments(pp$zeit[-n], pp$pfad[-n], pp$zeit[-1],pp$pfad[-n], ...)
    # am Ende die Punkte, die die Sprungstellen charakterisieren
    points(pp$zeit[-c(1,n)],pp$pfad[-c(1,n)], pch = 16, ...)
  }
  
  return(pp)
}